using NUnit.Framework;

namespace NHibernate.Test.NHSpecificTest.NH2792 {
   public class Fixture : BugTestCase {
      [Test]
      public void PlainSQLQuery_MultipleSameParameters_ExecutesAndBindsParametersCorrectly() {
         using (var session = OpenSession()) {
            using (var transaction = session.BeginTransaction()) {
               using (var log = new SqlLogSpy()) {
                  ISQLQuery query = session.CreateSQLQuery(
                     "select {entity.*} from Entity {entity} where {entity}.Name = :param or {entity}.Description = :param"
                  );

                  query.SetString("param", "Some String");
                  query.AddEntity("entity", typeof(Entity));

                  // Note: Some drivers (e.g. SQLite) can execute the query, but some (e.g. OracleDataClient) fail.
                  Assert.DoesNotThrow(() => {
                     var result = query.List<Entity>();
                  });

                  string executedQuery = log.GetWholeLog().Substring(0, log.GetWholeLog().LastIndexOf(";"));

                  Assert.IsTrue(executedQuery.Contains("p0"));
                  Assert.IsTrue(executedQuery.Contains("p1"));
               }
            }
         }
      }
   }
}